==> easycom-0.0.6-py3-none-any.whl: easycom/device_config.py <==
DEVICE_CONFIG = [
    {
        "name": "Arduino",
        "pidvids": ["2341:0043", "2341:0010", "0403:6001"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "Pico",
        "pidvids": ["2E8A:0005"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "Teensy",
        "pidvids": ["16C0:0483", "16C0:0487"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "ESP32",
        "pidvids": ["10C4:EA60", "1A86:7523"],
        "default_baudrate": 115200,
        "default_timeout": 3
    },
    {
        "name": "STM32",
        "pidvids": ["0483:5740"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "CP210x",
        "pidvids": ["10C4:EA60"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "FTDI",
        "pidvids": ["0403:6001", "0403:6015"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "CH340",
        "pidvids": ["1A86:7523"],
        "default_baudrate": 9600,
        "default_timeout": 3
    },
    {
        "name": "Prolific",
        "pidvids": ["067B:2303"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "RaspberryPi",
        "pidvids": ["2E8A:000A"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "NRF52840",
        "pidvids": ["1915:520A"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "MCP2200",
        "pidvids": ["04D8:00DD"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "EFM32",
        "pidvids": ["10C4:E005"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "STLink",
        "pidvids": ["0483:374B"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "FT232H",
        "pidvids": ["0403:6015"],
        "default_baudrate": 3000000,
        "default_timeout": 2
    },
    {
        "name": "FX2LP",
        "pidvids": ["04B4:8613"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "LPC11Uxx",
        "pidvids": ["1FC9:009C"],
        "default_baudrate": 115200,
        "default_timeout": 2
    }
]

==> easycom-1.0.1-py3-none-any.whl: easycom/device_config.py <==
DEVICE_CONFIG = [
    {
        "name": "Arduino",
        "vidpids": ["2341:0043", "2341:0010", "0403:6001"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "Pico",
        "vidpids": ["2E8A:0005", "2E8A:00c0"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "Teensy",
        "vidpids": ["16C0:0483", "16C0:0487"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "ESP32",
        "vidpids": ["10C4:EA60", "1A86:7523"],
        "default_baudrate": 115200,
        "default_timeout": 3
    },
    {
        "name": "STM32",
        "vidpids": ["0483:5740"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "CP210x",
        "vidpids": ["10C4:EA60"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "FTDI",
        "vidpids": ["0403:6001", "0403:6015"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "CH340",
        "vidpids": ["1A86:7523"],
        "default_baudrate": 9600,
        "default_timeout": 3
    },
    {
        "name": "Prolific",
        "vidpids": ["067B:2303"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "RaspberryPi",
        "vidpids": ["2E8A:000A"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "NRF52840",
        "vidpids": ["1915:520A"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "MCP2200",
        "vidpids": ["04D8:00DD"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "EFM32",
        "vidpids": ["10C4:E005"],
        "default_baudrate": 115200,
        "default_timeout": 2
    },
    {
        "name": "STLink",
        "vidpids": ["0483:374B"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "FT232H",
        "vidpids": ["0403:6015"],
        "default_baudrate": 3000000,
        "default_timeout": 2
    },
    {
        "name": "FX2LP",
        "vidpids": ["04B4:8613"],
        "default_baudrate": 9600,
        "default_timeout": 2
    },
    {
        "name": "LPC11Uxx",
        "vidpids": ["1FC9:009C"],
        "default_baudrate": 115200,
        "default_timeout": 2
    }
]
